@@ -12,10 +12,10 @@ setMethod("getValues", signature(x='RasterLayer', row='missing', nrows='missing'
 function(x, format='') {
 	
 	xx <- c(x@ncols, x@nrows)
-	f <- is.factor(x)
-	if (f) {
-		labs <- labels(x)
-	}
+#	f <- is.factor(x)
+#	if (f) {
+#		labs <- labels(x)
+#	}
 	
 	if ( inMemory(x) ) {
 		x <- x@data@values
@@ -27,8 +27,8 @@ function(x, format='') {
 
 	if (format=='matrix') { 
 		x <- matrix(x, ncol=xx[1], nrow=xx[2], byrow=TRUE) 
-	} else if (f) {
-		x <- factor(x)
+#	} else if (f) {
+#		x <- factor(x)
 		# set labels?
 	}	
 
